@@ -177,6 +177,11 @@ bool MixerAuth::LoadInternal()
 	return OAuthStreamKey::LoadInternal();
 }
 
+static const char *elixr_script = "\
+var elixr = document.createElement('script');\
+elixr.setAttribute('src','https://api.mixrelixr.com/scripts/elixr-emotes-embedded-chat.bundle.js');\
+document.head.appendChild(elixr);";
+
 void MixerAuth::LoadUI()
 {
 	if (!cef)
@@ -189,6 +194,7 @@ void MixerAuth::LoadUI()
 	OBSBasic::InitBrowserPanelSafeBlock();
 	OBSBasic *main = OBSBasic::Get();
 
+	std::string script = "";
 	std::string url;
 	url += "https://mixer.com/embed/chat/";
 	url += id;
@@ -206,6 +212,15 @@ void MixerAuth::LoadUI()
 	QCefWidget *browser = cef->create_widget(nullptr, url, panel_cookies);
 	chat->SetWidget(browser);
 
+	const int mxAddonChoice =
+		config_get_int(main->Config(), service(), "AddonChoice");
+	if (mxAddonChoice) {
+		if (mxAddonChoice & 0x1)
+			script += elixr_script;
+	}
+
+	browser->setStartupScript(script);
+
 	main->addDockWidget(Qt::RightDockWidgetArea, chat.data());
 	chatMenu.reset(main->AddDockWidget(chat.data()));
 
