@@ -38,6 +38,10 @@ TwitchAuth::TwitchAuth(const Def &d) : OAuthStreamKey(d)
 	cef->add_popup_whitelist_url(
 		"https://twitch.tv/popout/frankerfacez/chat?ffz-settings",
 		this);
+
+	/* enables javascript-based popups.  basically bttv popups */
+	cef->add_popup_whitelist_url("about:blank#blocked", this);
+
 	uiLoadTimer.setSingleShot(true);
 	uiLoadTimer.setInterval(500);
 	connect(&uiLoadTimer, &QTimer::timeout, this,
@@ -217,8 +221,16 @@ void TwitchAuth::LoadUI()
 	cef->add_force_popup_url(moderation_tools_url, chat.data());
 
 	script = "localStorage.setItem('twilight.theme', 1);";
-	script += bttv_script;
-	script += ffz_script;
+
+	const int twAddonChoice =
+		config_get_int(main->Config(), service(), "AddonChoice");
+	if (twAddonChoice) {
+		if (twAddonChoice & 0x1)
+			script += bttv_script;
+		if (twAddonChoice & 0x2)
+			script += ffz_script;
+	}
+
 	browser->setStartupScript(script);
 
 	main->addDockWidget(Qt::RightDockWidgetArea, chat.data());
@@ -261,8 +273,15 @@ void TwitchAuth::LoadSecondaryUIPanes()
 	script += name;
 	script += "/dashboard/live";
 	script += referrer_script2;
-	script += bttv_script;
-	script += ffz_script;
+
+	const int twAddonChoice =
+		config_get_int(main->Config(), service(), "AddonChoice");
+	if (twAddonChoice) {
+		if (twAddonChoice & 0x1)
+			script += bttv_script;
+		if (twAddonChoice & 0x2)
+			script += ffz_script;
+	}
 
 	/* ----------------------------------- */
 
