@@ -115,7 +115,10 @@ private:
 	bool advancedChanged = false;
 	int pageIndex = 0;
 	bool loading = true;
+	bool forceAuthReload = false;
 	std::string savedTheme;
+	int sampleRateIndex = 0;
+	int channelIndex = 0;
 
 	int lastSimpleRecQualityIdx = 0;
 	int lastChannelSetupIdx = 0;
@@ -231,6 +234,8 @@ private:
 	void OnOAuthStreamKeyConnected();
 	void OnAuthConnected();
 	QString lastService;
+	int prevLangIndex;
+	bool prevBrowserAccel;
 private slots:
 	void UpdateServerList();
 	void UpdateKeyLink();
@@ -300,6 +305,8 @@ private:
 	QIcon GetHotkeysIcon() const;
 	QIcon GetAdvancedIcon() const;
 
+	int CurrentFLVTrack();
+
 private slots:
 	void on_theme_activated(int idx);
 
