@@ -93,6 +93,11 @@ struct mp_media {
 
 	bool thread_valid;
 	pthread_t thread;
+
+	bool pause;
+	bool reset_ts;
+	bool seek;
+	int64_t seek_pos;
 };
 
 typedef struct mp_media mp_media_t;
@@ -119,6 +124,9 @@ extern void mp_media_free(mp_media_t *media);
 
 extern void mp_media_play(mp_media_t *media, bool loop);
 extern void mp_media_stop(mp_media_t *media);
+extern void mp_media_play_pause(mp_media_t *media, bool pause);
+extern int64_t mp_get_current_time(mp_media_t *m);
+extern void mp_media_seek_to(mp_media_t *m, int64_t pos);
 
 /* #define DETAILED_DEBUG_INFO */
 
