@@ -265,7 +265,9 @@ static struct obs_source_info image_source_info = {
 	.get_height = image_source_getheight,
 	.video_render = image_source_render,
 	.video_tick = image_source_tick,
-	.get_properties = image_source_properties};
+	.get_properties = image_source_properties,
+	.icon_type = OBS_ICON_TYPE_IMAGE,
+};
 
 OBS_DECLARE_MODULE()
 OBS_MODULE_USE_DEFAULT_LOCALE("image-source", "en-US")
@@ -275,12 +277,14 @@ MODULE_EXPORT const char *obs_module_description(void)
 }
 
 extern struct obs_source_info slideshow_info;
-extern struct obs_source_info color_source_info;
+extern struct obs_source_info color_source_info_v1;
+extern struct obs_source_info color_source_info_v2;
 
 bool obs_module_load(void)
 {
 	obs_register_source(&image_source_info);
-	obs_register_source(&color_source_info);
+	obs_register_source(&color_source_info_v1);
+	obs_register_source(&color_source_info_v2);
 	obs_register_source(&slideshow_info);
 	return true;
 }
