@@ -594,6 +594,7 @@ struct obs_source_info pulse_input_capture = {
 	.update = pulse_update,
 	.get_defaults = pulse_defaults,
 	.get_properties = pulse_input_properties,
+	.icon_type = OBS_ICON_TYPE_AUDIO_INPUT,
 };
 
 struct obs_source_info pulse_output_capture = {
@@ -607,4 +608,5 @@ struct obs_source_info pulse_output_capture = {
 	.update = pulse_update,
 	.get_defaults = pulse_defaults,
 	.get_properties = pulse_output_properties,
+	.icon_type = OBS_ICON_TYPE_AUDIO_OUTPUT,
 };
