@@ -4,9 +4,10 @@
 #include <windows.h>
 
 #include <obs-module.h>
-#include "nvEncodeAPI.h"
+#include "external/nvEncodeAPI.h"
 
-typedef NVENCSTATUS (NVENCAPI *NV_CREATE_INSTANCE_FUNC)(NV_ENCODE_API_FUNCTION_LIST*);
+typedef NVENCSTATUS(NVENCAPI *NV_CREATE_INSTANCE_FUNC)(
+	NV_ENCODE_API_FUNCTION_LIST *);
 
 extern const char *nv_error_name(NVENCSTATUS err);
 extern NV_ENCODE_API_FUNCTION_LIST nv;
