@@ -3,6 +3,8 @@
 #include <graphics/vec2.h>
 #include <graphics/vec4.h>
 
+/* clang-format off */
+
 #define SETTING_OPACITY                "opacity"
 #define SETTING_CONTRAST               "contrast"
 #define SETTING_BRIGHTNESS             "brightness"
@@ -21,28 +23,30 @@
 #define TEXT_SIMILARITY                obs_module_text("Similarity")
 #define TEXT_SMOOTHNESS                obs_module_text("Smoothness")
 
+/* clang-format on */
+
 struct color_key_filter_data {
-	obs_source_t                   *context;
+	obs_source_t *context;
 
-	gs_effect_t                    *effect;
+	gs_effect_t *effect;
 
-	gs_eparam_t                    *color_param;
-	gs_eparam_t                    *contrast_param;
-	gs_eparam_t                    *brightness_param;
-	gs_eparam_t                    *gamma_param;
+	gs_eparam_t *color_param;
+	gs_eparam_t *contrast_param;
+	gs_eparam_t *brightness_param;
+	gs_eparam_t *gamma_param;
 
-	gs_eparam_t                    *key_color_param;
-	gs_eparam_t                    *similarity_param;
-	gs_eparam_t                    *smoothness_param;
+	gs_eparam_t *key_color_param;
+	gs_eparam_t *similarity_param;
+	gs_eparam_t *smoothness_param;
 
-	struct vec4                    color;
-	float                          contrast;
-	float                          brightness;
-	float                          gamma;
+	struct vec4 color;
+	float contrast;
+	float brightness;
+	float gamma;
 
-	struct vec4                    key_color;
-	float                          similarity;
-	float                          smoothness;
+	struct vec4 key_color;
+	float similarity;
+	float smoothness;
 };
 
 static const char *color_key_name(void *unused)
@@ -51,18 +55,18 @@ static const char *color_key_name(void *unused)
 	return obs_module_text("ColorKeyFilter");
 }
 
-static inline void color_settings_update(
-		struct color_key_filter_data *filter, obs_data_t *settings)
+static inline void color_settings_update(struct color_key_filter_data *filter,
+					 obs_data_t *settings)
 {
-	uint32_t opacity = (uint32_t)obs_data_get_int(settings,
-			SETTING_OPACITY);
+	uint32_t opacity =
+		(uint32_t)obs_data_get_int(settings, SETTING_OPACITY);
 	uint32_t color = 0xFFFFFF | (((opacity * 255) / 100) << 24);
 	double contrast = obs_data_get_double(settings, SETTING_CONTRAST);
 	double brightness = obs_data_get_double(settings, SETTING_BRIGHTNESS);
 	double gamma = obs_data_get_double(settings, SETTING_GAMMA);
 
-	contrast = (contrast < 0.0) ?
-		(1.0 / (-contrast + 1.0)) : (contrast + 1.0);
+	contrast = (contrast < 0.0) ? (1.0 / (-contrast + 1.0))
+				    : (contrast + 1.0);
 
 	brightness *= 0.5;
 
@@ -75,15 +79,15 @@ static inline void color_settings_update(
 	vec4_from_rgba(&filter->color, color);
 }
 
-static inline void key_settings_update(
-		struct color_key_filter_data *filter, obs_data_t *settings)
+static inline void key_settings_update(struct color_key_filter_data *filter,
+				       obs_data_t *settings)
 {
 	int64_t similarity = obs_data_get_int(settings, SETTING_SIMILARITY);
 	int64_t smoothness = obs_data_get_int(settings, SETTING_SMOOTHNESS);
-	uint32_t key_color = (uint32_t)obs_data_get_int(settings,
-			SETTING_KEY_COLOR);
-	const char *key_type = obs_data_get_string(settings,
-			SETTING_COLOR_TYPE);
+	uint32_t key_color =
+		(uint32_t)obs_data_get_int(settings, SETTING_KEY_COLOR);
+	const char *key_type =
+		obs_data_get_string(settings, SETTING_COLOR_TYPE);
 
 	if (strcmp(key_type, "green") == 0)
 		key_color = 0x00FF00;
@@ -133,20 +137,20 @@ static void *color_key_create(obs_data_t *settings, obs_source_t *context)
 
 	filter->effect = gs_effect_create_from_file(effect_path, NULL);
 	if (filter->effect) {
-		filter->color_param = gs_effect_get_param_by_name(
-				filter->effect, "color");
-		filter->contrast_param = gs_effect_get_param_by_name(
-				filter->effect, "contrast");
+		filter->color_param =
+			gs_effect_get_param_by_name(filter->effect, "color");
+		filter->contrast_param =
+			gs_effect_get_param_by_name(filter->effect, "contrast");
 		filter->brightness_param = gs_effect_get_param_by_name(
-				filter->effect, "brightness");
-		filter->gamma_param = gs_effect_get_param_by_name(
-				filter->effect, "gamma");
+			filter->effect, "brightness");
+		filter->gamma_param =
+			gs_effect_get_param_by_name(filter->effect, "gamma");
 		filter->key_color_param = gs_effect_get_param_by_name(
-				filter->effect, "key_color");
+			filter->effect, "key_color");
 		filter->similarity_param = gs_effect_get_param_by_name(
-				filter->effect, "similarity");
+			filter->effect, "similarity");
 		filter->smoothness_param = gs_effect_get_param_by_name(
-				filter->effect, "smoothness");
+			filter->effect, "smoothness");
 	}
 
 	obs_leave_graphics();
@@ -167,7 +171,7 @@ static void color_key_render(void *data, gs_effect_t *effect)
 	struct color_key_filter_data *filter = data;
 
 	if (!obs_source_process_filter_begin(filter->context, GS_RGBA,
-				OBS_ALLOW_DIRECT_RENDERING))
+					     OBS_ALLOW_DIRECT_RENDERING))
 		return;
 
 	gs_effect_set_vec4(filter->color_param, &filter->color);
@@ -184,13 +188,13 @@ static void color_key_render(void *data, gs_effect_t *effect)
 }
 
 static bool key_type_changed(obs_properties_t *props, obs_property_t *p,
-		obs_data_t *settings)
+			     obs_data_t *settings)
 {
 	const char *type = obs_data_get_string(settings, SETTING_COLOR_TYPE);
 	bool custom = strcmp(type, "custom") == 0;
 
 	obs_property_set_visible(obs_properties_get(props, SETTING_KEY_COLOR),
-			custom);
+				 custom);
 
 	UNUSED_PARAMETER(p);
 	return true;
@@ -200,32 +204,33 @@ static obs_properties_t *color_key_properties(void *data)
 {
 	obs_properties_t *props = obs_properties_create();
 
-	obs_property_t *p = obs_properties_add_list(props,
-			SETTING_COLOR_TYPE, TEXT_COLOR_TYPE,
-			OBS_COMBO_TYPE_LIST, OBS_COMBO_FORMAT_STRING);
+	obs_property_t *p = obs_properties_add_list(props, SETTING_COLOR_TYPE,
+						    TEXT_COLOR_TYPE,
+						    OBS_COMBO_TYPE_LIST,
+						    OBS_COMBO_FORMAT_STRING);
 	obs_property_list_add_string(p, obs_module_text("Green"), "green");
 	obs_property_list_add_string(p, obs_module_text("Blue"), "blue");
 	obs_property_list_add_string(p, obs_module_text("Red"), "red");
 	obs_property_list_add_string(p, obs_module_text("Magenta"), "magenta");
 	obs_property_list_add_string(p, obs_module_text("CustomColor"),
-			"custom");
+				     "custom");
 
 	obs_property_set_modified_callback(p, key_type_changed);
 
 	obs_properties_add_color(props, SETTING_KEY_COLOR, TEXT_KEY_COLOR);
 	obs_properties_add_int_slider(props, SETTING_SIMILARITY,
-			TEXT_SIMILARITY, 1, 1000, 1);
+				      TEXT_SIMILARITY, 1, 1000, 1);
 	obs_properties_add_int_slider(props, SETTING_SMOOTHNESS,
-			TEXT_SMOOTHNESS, 1, 1000, 1);
+				      TEXT_SMOOTHNESS, 1, 1000, 1);
 
-	obs_properties_add_int_slider(props, SETTING_OPACITY, TEXT_OPACITY,
-			0, 100, 1);
-	obs_properties_add_float_slider(props, SETTING_CONTRAST,
-			TEXT_CONTRAST, -1.0, 1.0, 0.01);
+	obs_properties_add_int_slider(props, SETTING_OPACITY, TEXT_OPACITY, 0,
+				      100, 1);
+	obs_properties_add_float_slider(props, SETTING_CONTRAST, TEXT_CONTRAST,
+					-1.0, 1.0, 0.01);
 	obs_properties_add_float_slider(props, SETTING_BRIGHTNESS,
-			TEXT_BRIGHTNESS, -1.0, 1.0, 0.01);
-	obs_properties_add_float_slider(props, SETTING_GAMMA,
-			TEXT_GAMMA, -1.0, 1.0, 0.01);
+					TEXT_BRIGHTNESS, -1.0, 1.0, 0.01);
+	obs_properties_add_float_slider(props, SETTING_GAMMA, TEXT_GAMMA, -1.0,
+					1.0, 0.01);
 
 	UNUSED_PARAMETER(data);
 	return props;
@@ -244,14 +249,14 @@ static void color_key_defaults(obs_data_t *settings)
 }
 
 struct obs_source_info color_key_filter = {
-	.id                            = "color_key_filter",
-	.type                          = OBS_SOURCE_TYPE_FILTER,
-	.output_flags                  = OBS_SOURCE_VIDEO,
-	.get_name                      = color_key_name,
-	.create                        = color_key_create,
-	.destroy                       = color_key_destroy,
-	.video_render                  = color_key_render,
-	.update                        = color_key_update,
-	.get_properties                = color_key_properties,
-	.get_defaults                  = color_key_defaults
+	.id = "color_key_filter",
+	.type = OBS_SOURCE_TYPE_FILTER,
+	.output_flags = OBS_SOURCE_VIDEO,
+	.get_name = color_key_name,
+	.create = color_key_create,
+	.destroy = color_key_destroy,
+	.video_render = color_key_render,
+	.update = color_key_update,
+	.get_properties = color_key_properties,
+	.get_defaults = color_key_defaults,
 };
